Categorize top-level map keys. Useful for marking a particular set of keys as public.
Categorize top-level map keys. Useful for marking a particular set of keys as public.
(keyset m group)Returns the set of keys for group.
Returns the set of keys for `group`.
(select m group)Returns a map of the group keys in m.
Returns a map of the `group` keys in `m`.
(set-keys m group ks)Adds ks to key group for m.
Adds `ks` to key `group` for `m`.
(with-keys m group ks)Merges ks to key group for m.
Merges `ks` to key `group` for `m`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |